<?php

namespace App\Http\Controllers;

use App\Models\Contact;
use App\Models\Product;
use App\Models\Newsletter;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;


class AdminController extends Controller
{
    public function dashboard()
    {
        $data['total_product'] = Product::count();
        $data['categories'] = DB::table('products')
                ->select('category', DB::raw('count(*) as product_quantity'))
                ->groupBy('category')
                ->get();
        $data['total_categories'] = DB::table('products')
            ->select('category')
            ->distinct()
            ->count('category');
        return view('adexcell-store.frontend.pages.admin.dashboard_home',$data);
    }
    public function products()
    {
        $data['products']=Product::get();
        return view('adexcell-store.frontend.pages.admin.products',$data);
    }

    public function addProduct()
    {
        return view('adexcell-store.frontend.pages.admin.add-product');
    }
    public function updateProduct()
    {
        $data['products']=Product::get();
        return view('adexcell-store.frontend.pages.admin.update-product',$data);
    }

    public function user()
    {
        return view('adexcell-store.frontend.pages.admin.user');
    }
    public function coupon()
    {
        return view('adexcell-store.frontend.pages.admin.coupon');
    }
    public function profile()
    {
        return view('adexcell-store.frontend.pages.admin.profile');
    }

    public function newsLetterLst()
    {
        $data['newsLetters']=Newsletter::get();
        return view('adexcell-store.frontend.pages.admin.newsLetter_list',$data);
    }
    public function contactUslist()
    {
        $data['contacts']=Contact::get();
        return view('adexcell-store.frontend.pages.admin.contact_list',$data);
    }

    // login
    public function login(Request $request)
    {
        // Validate the login credentials
        $request->validate([
            'email' => 'required|email',
            'password' => 'required|min:4',
        ]);

        // Attempt to authenticate the user
        if (Auth::attempt($request->only('email', 'password'))) {
            // Regenerate the session to prevent fixation attacks
            $request->session()->regenerate();

            // Redirect the user to their intended location or default dashboard
            return redirect()->intended('/admin/dashboard')->with('success', 'Logged in successfully.');
        }

        // If authentication fails, redirect back with an error message
        return back()->withErrors([
            'errors' => 'The provided credentials do not match our records.',
        ]);
    }

    //logout
    public function logout(Request $request)
    {
        Auth::logout();

        // Invalidate the session
        $request->session()->invalidate();

        // Regenerate the CSRF token
        $request->session()->regenerateToken();

        return redirect('/sign-in')->with('success', 'Logged out successfully.');
    }


    public function destroyNewsletter($id)
    {
        $newsLetter = Newsletter::findOrFail($id);
        $newsLetter->delete();

        return redirect()->back()->with('success', 'Newsletter deleted successfully.');
    }

    public function destroyContact($id)
    {
        $contact = Contact::findOrFail($id); // Find the contact by ID or fail
        $contact->delete(); // Delete the contact
    
        return redirect()->back()->with('success', 'Contact deleted successfully.');
    }


    public function updateProfilePicture(Request $request)
    {
        $request->validate([
            'profile_picture' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        $user = User::where('id',Auth::user()->id)->first();
        if ($request->profile_picture) {
            Storage::delete($user->profile_picture);
        }

        $path = $request->file('profile_picture')->store('profile_pictures', 'public');
        $user->profile_picture = $path;
        $user->save();

        return redirect()->back()->with('success', 'Profile picture updated successfully!');

    }



}
