<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Product;

class ProductController extends Controller
{
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'price' => 'required|numeric',
            'description' => 'required|string',
            'category' => 'required|string',
            'photo' => 'nullable|image|mimes:jpg,png,jpeg|max:2048',
        ]);
        $photoPath = null;
        if ($request->hasFile('photo')) {
            $photoPath = $request->file('photo')->store('product_photos', 'public');
        }

        Product::create([
            'name' => $request->input('name'),
            'price' => $request->input('price'),
            'description' => $request->input('description'),
            'category' => $request->input('category'),
            'photo' => $photoPath,
        ]);

        return redirect()->route('admin.addProduct')->with('success', 'Product added successfully!');
    }
    public function edit($id)
    {
        $product = Product::findOrFail($id); // Load product by ID
        return view('adexcell-store.frontend.pages.admin.updatethis_product', compact('product')); // Pass product to the view
    }



    public function update(Request $request, $id)
    {
        $validated = $request->validate([
            'name' => 'required|string|max:255',
            'price' => 'required|numeric|min:0',
            'description' => 'nullable|string',
            'category' => 'required|string',
            'photo' => 'nullable|image|max:2048', // Optional file validation
        ]);

        $product = Product::findOrFail($id);

        // Handle file upload if a new file is provided
        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $path = $file->store('product_photos', 'public');
            $validated['photo'] = $path;
        }

        $product->update($validated); // Update product data
        return redirect()->route('admin.updateProduct')->with('success', 'Product updated successfully.');
    }

    public function destroy($id)
    {
        $product = Product::findOrFail($id);
        $product->delete();

        // Flash a success message
        return redirect()->back()->with('success', 'Product deleted successfully!');
    }


}
