@extends('adexcell-store.frontend.pages.admin.dashboard')
@section('dashboard_content')

<section class="flex justify-center py-10">
    <div class="w-full max-w-3xl p-8 bg-white rounded-lg shadow-lg transform transition duration-500 hover:scale-105">
        <h2 class="text-2xl font-bold text-center text-blue-600 mb-8">Add New Product</h2>
        @if(session('success'))
            <div class="bg-green-500 text-white p-4 rounded-lg mb-4 text-center">
                {{ session('success') }}
            </div>
        @endif

        @if ($errors->any())
            <div class="bg-red-500 text-white p-4 rounded-lg mb-4">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
        @endif

        <form method="POST" action="{{ route('products.store') }}" enctype="multipart/form-data" class="space-y-6">
            @csrf

            <!-- Product Photo -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="photo">Product Photo</label>
                <input type="file" id="photo" name="photo" accept="image/*"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400"
                    onchange="previewImage(event)">
                <!-- Image Preview -->
                <div class="mt-4 flex justify-center">
                    <img id="image_preview" src="" alt="Image Preview" class="w-32 h-32 object-cover rounded-md hidden">
                </div>
            </div>

            <!-- Product Name -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="name">Product Name</label>
                <input type="text" id="name" name="name" placeholder="Enter product name"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400"
                    value="{{ old('name') }}">
            </div>

            <!-- Price -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="price">Price</label>
                <input type="number" id="price" name="price" placeholder="Enter product price" step="0.01"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400"
                    value="{{ old('price') }}">
            </div>

            <!-- Description -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="description">Description</label>
                <textarea id="description" name="description" rows="4" placeholder="Enter product description"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400">{{ old('description') }}</textarea>
            </div>

            <!-- Category -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="category">Category</label>
                <select id="category" name="category"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400">
                    <option value="" disabled selected>Select a category</option>
                    <option value="software" {{ old('category') == 'software' ? 'selected' : '' }}>Software</option>
                    <option value="streaming-services" {{ old('category') == 'streaming-services' ? 'selected' : '' }}>Subscription Services</option>
                    <option value="gift-cards" {{ old('category') == 'gift-cards' ? 'selected' : '' }}>Gift Cards</option>
                    <option value="gaming" {{ old('category') == 'gaming' ? 'selected' : '' }}>Gaming</option>
                    <option value="vpn-services" {{ old('category') == 'vpn-services' ? 'selected' : '' }}>VPN Services</option>
                    <option value="music-streaming" {{ old('category') == 'music-streaming' ? 'selected' : '' }}>Music Streaming</option>
                    <option value="software-tools" {{ old('category') == 'software-tools' ? 'selected' : '' }}>Software Tools</option>
                    <option value="artificial-intelligence" {{ old('category') == 'artificial-intelligence' ? 'selected' : '' }}>Artificial Intelligence</option>
                    <option value="other-services" {{ old('category') == 'other-services' ? 'selected' : '' }}>Other Services</option>
                </select>
            </div>

            <!-- Submit Button -->
            <div class="text-center">
                <button type="submit"
                    class="w-full sm:w-auto bg-blue-600 text-white font-bold py-2 px-4 rounded-md transition duration-300 ease-in-out transform hover:scale-105 hover:bg-blue-700 focus:ring-2 focus:ring-blue-400">
                    Add Product
                </button>
            </div>
            
        </form>
    </div>
</section>

@push('dashboard-scripts')
    <script>
        function previewImage(event) {
            const imagePreview = document.getElementById('image_preview');
            const file = event.target.files[0];

            if (file) {
                const reader = new FileReader();
                reader.onload = function (e) {
                    imagePreview.src = e.target.result;
                    imagePreview.classList.remove('hidden');
                };
                reader.readAsDataURL(file);
            }
        }
    </script>
@endpush

@endsection
