@extends('adexcell-store.frontend.pages.admin.dashboard')
@section('dashboard_content')

<section class="py-10 px-4">
    <div class="max-w-6xl mx-auto bg-white p-8 rounded-lg shadow-lg mb-10">
        <h2 class="text-2xl font-bold text-blue-600 mb-6 text-center">Generate Coupon Codes</h2>

        <form class="space-y-6">
            <!-- Coupon Code Input -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="coupon_code">Coupon Code</label>
                <input type="text" id="coupon_code" placeholder="Enter coupon code"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400">
            </div>

            <!-- Discount Price Input -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="discount_price">Discount Price</label>
                <input type="number" id="discount_price" placeholder="Enter discount price"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400">
            </div>

            <!-- Generate Button -->
            <div class="text-center">
                <button type="button"
                    class="w-full sm:w-auto bg-blue-600 text-white font-bold py-2 px-4 rounded-md transition duration-300 ease-in-out hover:scale-105 hover:bg-blue-700"
                    onclick="generateCoupon()">
                    Generate Coupon
                </button>
            </div>
        </form>
    </div>

    <!-- Coupons Table -->
    <div class="max-w-6xl mx-auto bg-white p-8 rounded-lg shadow-lg">
        <h2 class="text-2xl font-bold text-blue-600 mb-6 text-center">Existing Coupons</h2>

        <div class="overflow-x-auto">
            <table class="min-w-full bg-white border border-gray-200">
                <thead class="bg-blue-600 text-white">
                    <tr>
                        <th class="py-3 px-6 text-left font-semibold">Coupon Code</th>
                        <th class="py-3 px-6 text-left font-semibold">Discount Price</th>
                        <th class="py-3 px-6 text-center font-semibold">Actions</th>
                    </tr>
                </thead>
                <tbody id="coupons_table_body">
                    <!-- Coupons will be populated here dynamically -->
                </tbody>
            </table>
        </div>
    </div>
</section>

@push('dashboard-scripts')
    <script>
        const coupons = [];

        function generateCoupon() {
            const couponCode = document.getElementById('coupon_code').value;
            const discountPrice = document.getElementById('discount_price').value;

            if (!couponCode || !discountPrice) {
                alert("Please enter both coupon code and discount price.");
                return;
            }

            const coupon = { code: couponCode, discount: discountPrice };
            coupons.push(coupon);
            displayCoupons();
            resetForm();
        }

        function displayCoupons() {
            const couponsTableBody = document.getElementById('coupons_table_body');
            couponsTableBody.innerHTML = '';

            coupons.forEach((coupon, index) => {
                const row = `
                        <tr class="border-b hover:bg-gray-100">
                            <td class="py-4 px-6">${coupon.code}</td>
                            <td class="py-4 px-6">${coupon.discount}</td>
                            <td class="py-4 px-6 text-center">
                                <button onclick="deleteCoupon(${index})" class="text-red-500 hover:text-red-700">
                                    <i class="fas fa-trash"></i>
                                </button>
                            </td>
                        </tr>
                    `;
                couponsTableBody.innerHTML += row;
            });
        }

        function deleteCoupon(index) {
            if (confirm('Are you sure you want to delete this coupon?')) {
                coupons.splice(index, 1);
                displayCoupons();
            }
        }

        function resetForm() {
            document.getElementById('coupon_code').value = '';
            document.getElementById('discount_price').value = '';
        }
    </script>

@endpush

@endsection