@extends('adexcell-store.frontend.layouts.app')
@section('content')

@push('styles')
    <style>
        /* Custom styles for animations and effects */
        .checkout-card {
            transition: transform 0.3s, background-color 0.3s;
            background-color: rgba(34, 34, 34, 0.9);
            border-radius: 15px;

            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.5);
        }

        .checkout-card:hover {
            transform: scale(1.02);
            background-color: rgba(255, 255, 255, 0.05);
        }

        .btn-hover {
            transition: transform 0.3s, background-color 0.3s;
        }

        .btn-hover:hover {
            transform: scale(1.1);
            background-color: #4f46e5;
        }

        .input-field {
            border: 1px solid #4f46e5;
        }

        /* Modal styling */
        .modal-overlay {
            position: fixed;
            inset: 0;
            background-color: rgba(0, 0, 0, 0.5);
            display: flex;
            align-items: center;
            justify-content: center;
            z-index: 1000;
        }

        .modal-content {
            background: white;
            padding: 20px;
            border-radius: 8px;
            max-width: 400px;
            width: 90%;
            text-align: center;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.3);
        }
    </style>
@endpush

<div class="bg-gray-900 text-gray-200 py-10 px-4">

    <div class="max-w-4xl mx-auto">

        <div class="checkout-card p-8">
            @if(session('success'))
                <div class="bg-green-500 text-white text-center py-2 rounded">
                    {{ session('success') }}
                </div>
            @endif
            <h2 class="text-3xl font-bold text-blue-500 text-center mb-6">Product Checkout</h2>

           <div class="flex mb-6">
                <img
                    src="{{ $productDetails['photo'] ? asset('storage/' . $productDetails['photo']) : 'https://i.imgur.com/zF2YmxZ.jpg' }}"
                    alt="{{ $productDetails['name'] }}"
                    class="w-32 h-32 rounded-lg shadow-md mr-4"
                >
                <div class="flex flex-col justify-center">
                    <h3 class="text-xl font-semibold">{{ $productDetails['name'] }}</h3>
                    <p class="text-gray-400">Category: <span class="text-gray-300">{{ $productDetails['category'] ?? 'N/A' }}</span></p>
                    <p class="text-lg font-bold text-green-500">${{ $productDetails['price'] }}</p>
                </div>
            </div>



            <form action="{{ route('checkout.store') }}" method="POST">
                @csrf
                <!-- Hidden Inputs -->
                <input type="hidden" name="product_name" value="{{ $productDetails['name'] }}">
                <input type="hidden" name="product_id" value="{{ $productDetails['id'] }}">
                <input type="hidden" name="category" value="{{ $productDetails['category'] }}">
                <input type="hidden" name="product_price" value="{{ $productDetails['price'] }}">

                <!-- User Information -->
                <div class="mb-6">
                    <label class="text-gray-300" for="username">Your Name</label>
                    <input type="text" id="username" name="username"
                        class="input-field bg-gray-800 text-gray-200 py-2 px-4 rounded transition duration-200 w-full"
                        placeholder="Enter your name" required>
                </div>

                <div class="mb-6">
                    <label class="text-gray-300" for="contact-number">Contact Number</label>
                    <input type="tel" id="contact-number" name="contact_number"
                        class="input-field bg-gray-800 text-gray-200 py-2 px-4 rounded transition duration-200 w-full"
                        placeholder="Enter your contact number" required>
                </div>

                <div class="mb-6">
                    <label class="text-gray-300" for="payment-number">Payment Sending Number</label>
                    <input type="tel" id="payment-number" name="payment_number"
                        class="input-field bg-gray-800 text-gray-200 py-2 px-4 rounded transition duration-200 w-full"
                        placeholder="Enter the number from which you sent the payment" required>
                </div>

                <div class="mb-6">
                    <label class="text-gray-300" for="payment-method">Payment Method</label>
                    <select id="payment-method" name="payment_method"
                        class="input-field bg-gray-800 text-gray-200 py-2 px-4 rounded transition duration-200 w-full">
                        <option value="bkash">bKash</option>
                        <option value="nagad">Nagad</option>
                        <option value="rocket">Rocket</option>
                    </select>
                </div>

                <div class="mb-6">
                    <label class="text-gray-300" for="transaction-id">Transaction ID</label>
                    <input type="text" id="transaction-id" name="transaction_id"
                        class="input-field bg-gray-800 text-gray-200 py-2 px-4 rounded transition duration-200 w-full"
                        placeholder="Enter transaction ID" required>
                </div>

                <div class="text-center">
                    <button type="submit"
                        class="btn-hover bg-blue-600 text-white py-3 px-6 rounded-lg transition duration-300">
                        Proceed
                    </button>
                </div>
            </form>

        </div>
    </div>
</div>

<!-- WhatsApp Modal -->
<div id="whatsapp-modal" class="modal-overlay hidden">
    <div class="modal-content">
        <h3 class="text-xl font-bold text-gray-800 mb-4">Please Confirm on WhatsApp</h3>
        <p class="text-gray-700 mb-6">After completing your payment, please message us on WhatsApp for confirmation.</p>
        <a href="https://wa.me/1911531111" target="_blank"
            class="bg-green-500 text-white py-2 px-4 rounded-lg font-medium transition hover:bg-green-600">
            Message Us on WhatsApp
        </a>
        <button onclick="closeWhatsAppModal()" class="mt-4 text-gray-600 underline">Close</button>
    </div>
</div>

@push('scripts')
    <script>
        function openWhatsAppModal() {
            document.getElementById('whatsapp-modal').classList.remove('hidden');
        }

        function closeWhatsAppModal() {
            document.getElementById('whatsapp-modal').classList.add('hidden');
        }
    </script>
@endpush

@endsection
