@extends('adexcell-store.frontend.layouts.app')
@section('content')

@push('styles')
    <style>
        /* Custom Animation */
        .fade-in {
            animation: fadeIn 0.8s ease-in-out;
        }

        @keyframes fadeIn {
            from {
                opacity: 0;
                transform: translateY(10px);
            }

            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .hover-scale:hover {
            transform: scale(1.03);
            box-shadow: 0px 6px 18px rgba(0, 0, 0, 0.1);
        }

        /* Button Styling */
        .order-button {
            padding: 0.5rem 1.5rem;
            font-size: 0.875rem;
            background: linear-gradient(135deg, #6a0dad, #ff69b4);
            color: white;
            border: none;
            border-radius: 4px;
            box-shadow: 0px 4px 12px rgba(106, 13, 173, 0.5);
            transition: transform 0.3s ease, box-shadow 0.3s ease;
            position: relative;
            overflow: hidden;
        }

        .order-button:hover {
            transform: scale(1.05);
            box-shadow: 0px 6px 18px rgba(106, 13, 173, 0.7);
        }

        /* Button Ripple Effect */
        .order-button::after {
            content: "";
            position: absolute;
            top: 50%;
            left: 50%;
            width: 300%;
            height: 300%;
            background-color: rgba(255, 255, 255, 0.3);
            border-radius: 50%;
            opacity: 0;
            transform: translate(-50%, -50%) scale(0.1);
            transition: opacity 0.4s, transform 0.4s;
        }

        .order-button:hover::after {
            opacity: 1;
            transform: translate(-50%, -50%) scale(1);
        }

        /* Card Styling */
        .product-card {
            background-color: #fff;
            border-radius: 8px;
            overflow: hidden;
            transition: transform 0.3s ease;
            box-shadow: 0px 4px 12px rgba(0, 0, 0, 0.1);
        }

        /* Highlighted Text */
        .product-name {
            font-size: 1.2rem;
            font-weight: 700;
            color: #333;
        }

        .product-price {
            font-size: 1.25rem;
            font-weight: 600;
            color: #6a0dad;
        }
    </style>
@endpush

<div class="container mx-auto px-4 py-10">
    <h1 class="text-3xl sm:text-4xl font-bold text-center text-[#5C26B5] mb-8">Our Products</h1>

    {{-- <div class="grid gap-6 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4">
        @foreach(['Sony LIV', 'Zee5', 'Canva Pro', 'Netflix', 'Google Pay Gift Card', 'Ullu', 'Amazon Prime', 'Ecommerce App', 'Matrimony Website', 'Voot', 'Disney Plus'] as $product)
            <div class="product-card hover-scale fade-in">
                <!-- Image Section -->
                <img src="https://i.imgur.com/zF2YmxZ.jpg" alt="{{ $product }}" class="w-full h-48 object-cover">

                <!-- Content Section -->
                <div class="p-4">
                    <h2 class="product-name mb-2">{{ $product }}</h2>
                    <h3 class="product-price mb-4">$13.90</h3>

                    <p class="text-sm text-gray-600 mb-4">
                        Discover the best features and benefits with {{ $product }}.
                    </p>

                    <div class="flex justify-end">
                        <a href="{{ route('checkout') }}"><button class="order-button">Order Now</button></a>
                    </div>
                </div>
            </div>
        @endforeach
    </div> --}}
    <div class="grid gap-6 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4">
        @foreach($products as $product)
            <div class="product-card hover-scale fade-in">
                <!-- Image Section -->
                <img 
                    src="{{ $product['photo'] ? asset('storage/' . $product['photo']) : 'https://i.imgur.com/zF2YmxZ.jpg' }}"
                    alt="{{ $product['name'] }}" 
                    class="w-full h-48 object-cover">

                <!-- Content Section -->
                <div class="p-4">
                    <h2 class="product-name mb-2">{{ $product['name'] }}</h2>
                    <h3 class="product-price mb-4">${{ $product['price'] }}</h3>

                    <p class="text-sm text-gray-600 mb-4">
                        {{ $product['description'] }}
                    </p>

                    <div class="flex justify-end">
                        <a href="{{ route('checkout', ['photo' => $product['photo'],'id' => $product['id'], 'name' => $product['name'],'category' => $product['category'], 'price' => $product['price']]) }}">
                            <button class="order-button">Order Now</button>
                        </a>
                    </div>
                </div>
            </div>
        @endforeach

    </div>
</div>

@endsection