<?php $__env->startSection('dashboard_content'); ?>

<section class="flex justify-center py-10">
    <div class="w-full max-w-3xl p-8 bg-white rounded-lg shadow-lg transform transition duration-500 hover:scale-105">
        <h2 class="text-2xl font-bold text-center text-blue-600 mb-8">Add New Product</h2>
        <?php if(session('success')): ?>
            <div class="bg-green-500 text-white p-4 rounded-lg mb-4 text-center">
                <?php echo e(session('success')); ?>

            </div>
        <?php endif; ?>

        <?php if($errors->any()): ?>
            <div class="bg-red-500 text-white p-4 rounded-lg mb-4">
                <ul>
                    <?php $__currentLoopData = $errors->all(); $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $error): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                        <li><?php echo e($error); ?></li>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                </ul>
            </div>
        <?php endif; ?>

        <form method="POST" action="<?php echo e(route('products.store')); ?>" enctype="multipart/form-data" class="space-y-6">
            <?php echo csrf_field(); ?>

            <!-- Product Photo -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="photo">Product Photo</label>
                <input type="file" id="photo" name="photo" accept="image/*"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400"
                    onchange="previewImage(event)">
                <!-- Image Preview -->
                <div class="mt-4 flex justify-center">
                    <img id="image_preview" src="" alt="Image Preview" class="w-32 h-32 object-cover rounded-md hidden">
                </div>
            </div>

            <!-- Product Name -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="name">Product Name</label>
                <input type="text" id="name" name="name" placeholder="Enter product name"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400"
                    value="<?php echo e(old('name')); ?>">
            </div>

            <!-- Price -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="price">Price</label>
                <input type="number" id="price" name="price" placeholder="Enter product price" step="0.01"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400"
                    value="<?php echo e(old('price')); ?>">
            </div>

            <!-- Description -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="description">Description</label>
                <textarea id="description" name="description" rows="4" placeholder="Enter product description"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400"><?php echo e(old('description')); ?></textarea>
            </div>

            <!-- Category -->
            <div>
                <label class="block text-gray-700 font-semibold mb-2" for="category">Category</label>
                <select id="category" name="category"
                    class="w-full border border-gray-300 p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-blue-400">
                    <option value="" disabled selected>Select a category</option>
                    <option value="software" <?php echo e(old('category') == 'software' ? 'selected' : ''); ?>>Software</option>
                    <option value="streaming-services" <?php echo e(old('category') == 'streaming-services' ? 'selected' : ''); ?>>Subscription Services</option>
                    <option value="gift-cards" <?php echo e(old('category') == 'gift-cards' ? 'selected' : ''); ?>>Gift Cards</option>
                    <option value="gaming" <?php echo e(old('category') == 'gaming' ? 'selected' : ''); ?>>Gaming</option>
                    <option value="vpn-services" <?php echo e(old('category') == 'vpn-services' ? 'selected' : ''); ?>>VPN Services</option>
                    <option value="music-streaming" <?php echo e(old('category') == 'music-streaming' ? 'selected' : ''); ?>>Music Streaming</option>
                    <option value="software-tools" <?php echo e(old('category') == 'software-tools' ? 'selected' : ''); ?>>Software Tools</option>
                    <option value="artificial-intelligence" <?php echo e(old('category') == 'artificial-intelligence' ? 'selected' : ''); ?>>Artificial Intelligence</option>
                    <option value="other-services" <?php echo e(old('category') == 'other-services' ? 'selected' : ''); ?>>Other Services</option>
                </select>
            </div>

            <!-- Submit Button -->
            <div class="text-center">
                <button type="submit"
                    class="w-full sm:w-auto bg-blue-600 text-white font-bold py-2 px-4 rounded-md transition duration-300 ease-in-out transform hover:scale-105 hover:bg-blue-700 focus:ring-2 focus:ring-blue-400">
                    Add Product
                </button>
            </div>
            
        </form>
    </div>
</section>

<?php $__env->startPush('dashboard-scripts'); ?>
    <script>
        function previewImage(event) {
            const imagePreview = document.getElementById('image_preview');
            const file = event.target.files[0];

            if (file) {
                const reader = new FileReader();
                reader.onload = function (e) {
                    imagePreview.src = e.target.result;
                    imagePreview.classList.remove('hidden');
                };
                reader.readAsDataURL(file);
            }
        }
    </script>
<?php $__env->stopPush(); ?>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('adexcell-store.frontend.pages.admin.dashboard', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH D:\laragon\www\adexcell-store\resources\views/adexcell-store/frontend/pages/admin/add-product.blade.php ENDPATH**/ ?>